﻿' EXAMPLE - SQL04 for Visual Basic using ADO.NET
' When you run this example, a new database is created with a single table
' that has an index.  Ten rows are inserted in random order.
' Finally all the data is read from the database using the index to order
' the results.
' 
' The following methods are illustrated:
'     Raima.Rdm.RdmConnection:
'         Close() Method
'         CreateCommand() Method
'         Open() Method
'         RdmConnection() Constructor
'     Raima.Rdm.RdmCommand:
'         CommandText Property
'         ExecuteNonQuery() Method
'         ExecuteReader() Method
'     Raima.Rdm.RdmDataReader:
'         Item[int] Property
'         Read() Method
' 
' They are fully document in http://docs.raima.com/rdm/.
' 
' For simplicity this example does not catch any thrown execptions
' but good programming practices would dictate that this occur in
' a full application.

' Raima.Rdm is the system module that contains the ADO.NET
' data provider for RDM
Imports Rdm = Raima.Rdm

Module SQL04

    Sub CreateDatabase()
        ' Attempt to create the database.  If the database already
        ' exists this will fail and we simply ignore the failure
        ' for this sample.
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local")
        conn.Open()

        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        Try
            Dim dropCmds(0 To 1) As String
            dropCmds(0) = "DROP DATABASE SQL04"
            dropCmds(1) = "COMMIT"

            For Each c In dropCmds
                cmd.CommandText = c
                cmd.ExecuteNonQuery()
            Next

        Catch ex As Exception
        End Try

        Dim createCmds(0 To 2) As String

        createCmds(0) = "CREATE DATABASE SQL04"
        createCmds(1) = "CREATE TABLE IndTab (id INTEGER PRIMARY KEY)"
        createCmds(2) = "COMMIT"

        For Each c In createCmds
            cmd.CommandText = c
            cmd.ExecuteNonQuery()
        Next

        conn.Close()
    End Sub

    Sub Main()
        CreateDatabase()

        ' Create the connection with a simple connection string
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local;database=SQL04;openmode=x")

        ' Open the connection to the database
        conn.Open()

        ' Create a new command
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        Dim rand As Random
        rand = New Random(1)

        ' Insert ten rows into the table with random data
        For ii = 1 To 10
            cmd.CommandText = "INSERT INTO IndTab VALUES " + Convert.ToString(rand.Next() Mod 100)
            cmd.ExecuteNonQuery()
        Next

        ' Scan through all the existing rows using the index for order
        cmd.CommandText = "SELECT id FROM IndTab order by id"
        Dim reader As Rdm.RdmDataReader
        reader = cmd.ExecuteReader()

        While (reader.Read())
            Console.WriteLine(reader.Item(0))
        End While

        conn.Close()

        Console.WriteLine("Hit <Enter> to continue")
        Console.ReadLine()
    End Sub
End Module
